<?php
namespace Flat101\Analytics\Block\Adminhtml\System\Config;

use Magento\Config\Block\System\Config\Form\Field;
use Magento\Framework\Data\Form\Element\AbstractElement;

class GtmChecker extends Field
{

    /** @var string */
    protected $_gtmCheckerButtonLabel = 'GTM Checker';

    /**
     * Set GTM Checker Button Label
     *
     * @param string $gtmCheckerButtonLabel
     * @return GtmChecker
     */
    public function setGtmCheckerButtonLabel(string $gtmCheckerButtonLabel): GtmChecker
    {
        $this->_gtmCheckerButtonLabel = $gtmCheckerButtonLabel;
        return $this;
    }

    /**
     * Set template to itself
     *
     * @return GtmChecker
     */
    protected function _prepareLayout()
    {
        parent::_prepareLayout();
        if (!$this->getTemplate()) {
            $this->setTemplate('Flat101_Analytics::system/config/gtm-checker.phtml');
        }
        return $this;
    }

    /**
     * Unset some non-related element parameters
     *
     * @param AbstractElement $element
     * @return string
     */
    public function render(AbstractElement $element): string
    {
        $element->unsScope()->unsCanUseWebsiteValue()->unsCanUseDefaultValue();
        return parent::render($element);
    }

    /**
     * Get the button and scripts contents
     *
     * @param AbstractElement $element
     * @return string
     */
    protected function _getElementHtml(AbstractElement $element)
    {
        $originalData = $element->getOriginalData();
        $buttonLabel = !empty($originalData['button_label']) ? $originalData['button_label'] : $this->_gtmCheckerButtonLabel;
        $this->addData(
            [
                'button_label' => __($buttonLabel),
                'html_id' => $element->getHtmlId(),
                'ajax_url' => $this->_urlBuilder->getUrl('flat101-analytics/system_config_gtmchecker/validate'),
            ]
        );

        return $this->_toHtml();
    }
}
