<?php
namespace Flat101\Analytics\Controller\Adminhtml\System\Config\Gtmchecker;

use Magento\Framework\Controller\Result\Json;
use Magento\Framework\Controller\Result\JsonFactory;
use Magento\Backend\App\Action;
use Flat101\Analytics\Model\GtmChecker\Validate as ModelValidator;
use Magento\Framework\DataObject;

class Validate extends Action
{
    /** @var JsonFactory */
    protected $resultJsonFactory;

    /** @var ModelValidator */
    protected $modelValidator;

    /**
     * @param Action\Context $context
     * @param JsonFactory $resultJsonFactory
     * @param ModelValidator $modelValidator
     */
    public function __construct(
        Action\Context $context,
        JsonFactory $resultJsonFactory,
        ModelValidator $modelValidator
    ) {
        parent::__construct($context);
        $this->resultJsonFactory = $resultJsonFactory;
        $this->modelValidator = $modelValidator;
    }

    /**
     * Check whether vat is valid
     *
     * @return Json
     */
    public function execute(): Json
    {
        $result = $this->validate();

        $resultJson = $this->resultJsonFactory->create();
        return $resultJson->setData([
            'valid' => (int)$result->getIsValid(),
            'message' => $result->getRequestMessage()
        ]);
    }

    /**
     * Perform GTM checker
     *
     * @return DataObject
     */
    protected function validate(): DataObject
    {
        return $this->modelValidator->searchGtmCode();
    }
}
