<?php
namespace Flat101\Analytics\Model\GtmChecker;

use Magento\Framework\DataObject;
use Magento\Framework\App\ResourceConnection;

class Validate
{
    CONST GTM_DEFAULT_CODE_FRAGMENT_1 = 'gtm';
    CONST GTM_DEFAULT_CODE_FRAGMENT_2 = 'Google Tag Manager';
    CONST GTM_DEFAULT_CODE_FRAGMENT_3 = 'googletagmanager';

    CONST GTM_EXCLUDED_FIELDS = [
        'flat101_analytics/general/gtm_code',
        'flat101_analytics/general/datalayer_name'
    ];

    CONST GA_ACTIVE_FIELD = 'google/analytics/active';

    /** @var ResourceConnection */
    protected $_resourceConnection;

    protected $_connection;

    public function __construct(
        ResourceConnection $resourceConnection
    ) {
        $this->_resourceConnection = $resourceConnection;
    }

    private function getCustomCollection()
    {
        $this->_connection = $this->_resourceConnection->getConnection();
        //Your custom sql query
        $query = "SELECT path FROM core_config_data ";
        $query .= "WHERE path NOT IN ('". implode("', '", self::GTM_EXCLUDED_FIELDS) ."') AND (path LIKE '%" . self::GTM_DEFAULT_CODE_FRAGMENT_1 . "%' OR value LIKE '%" . self::GTM_DEFAULT_CODE_FRAGMENT_1 . "%' OR value LIKE '%" . self::GTM_DEFAULT_CODE_FRAGMENT_2 . "%' OR value LIKE '%" . self::GTM_DEFAULT_CODE_FRAGMENT_3 . "%')";

        $collection = $this->_connection->fetchAll($query);
        return $collection;
    }

    private function checkGAActive()
    {
        $this->_connection = $this->_resourceConnection->getConnection();
        //Your custom sql query
        $query = "SELECT COUNT(*) AS total FROM core_config_data ";
        $query .= "WHERE path = '". self::GA_ACTIVE_FIELD ."' AND value = 1;";

        if ($this->_connection->fetchOne($query) == 1) {
            return true;
        }
        return false;
    }

    /**
     * Search any match for GTM Script code
     *
     * @return DataObject
     */
    public function searchGtmCode(): DataObject
    {
        // Default response
        $response = new DataObject([
            'is_valid' => false,
            'request_message' => __('Error searching GTM code.'),
        ]);

        try {
            if (count($gtmMatchCollection = $this->getCustomCollection()) > 0) {
                $matches = [];
                foreach ($gtmMatchCollection as $gtmMatch) {
                    $matches[] = $gtmMatch['path'];
                }

                $textMatches = implode('<br/> - ', $matches);
                $response->setRequestMessage(__('We had found %1 matches for GTM script code. Next fields contains GTM code: <br/>- %2', count($matches), $textMatches));
            } else {
                $response->setIsValid(true);
                $response->setRequestMessage(__('No matches for GTM script code. Nevertheless, please check if third party modules fill in this code.'));
            }

            if ($this->checkGAActive()) {
                $message = $response->getRequestMessage();
                $response->setRequestMessage($message . '<br/><br/>' . __('In addition, we notice you that Google Analytics is configured from Magento. Please disable it from Stores > Configuration > Sales > Google API.'));
            }
        } catch (\Exception $exception) {
            $response->setIsValid(false);
        }

        return $response;
    }
}
